@@ -139,7 +139,7 @@ make_mime_name (const char *mime_type)
 }
 
 static char *
-make_generic_mime_name (const char *mime_type)
+make_generic_mime_name (const char *mime_type, gboolean embedd_text)
 {
   char *generic_mime_type, *icon_name;
   char *p;
@@ -155,8 +155,11 @@ make_generic_mime_name (const char *mime_type)
   if ((p = strchr(generic_mime_type, '/')) != NULL)
     {
       *p = 0;
-  
-      icon_name = g_strconcat (ICON_NAME_MIME_PREFIX, generic_mime_type, NULL);
+
+      if (strcmp ("text", generic_mime_type) == 0 && embedd_text)
+	icon_name = g_strdup ("gnome-fs-regular");
+      else
+	icon_name = g_strconcat (ICON_NAME_MIME_PREFIX, generic_mime_type, NULL);
     }
   g_free (generic_mime_type);
   
@@ -168,24 +171,34 @@ static gboolean
 mimetype_supported_by_gdk_pixbuf (const char *mime_type)
 {
 	guint i;
-	static GHashTable *formats = NULL;
-	static const char *types [] = {
-		"image/x-bmp", "image/x-ico", "image/jpeg", "image/gif",
-		"image/png", "image/pnm", "image/ras", "image/tga",
-		"image/tiff", "image/wbmp", "image/x-xbitmap",
-		"image/x-xpixmap"
-	};
+	static GHashTable *formats_hash = NULL;
 
-	if (!formats) {
-		formats = g_hash_table_new (g_str_hash, g_str_equal);
+	if (!formats_hash) {
+		GSList *formats, *list;
+		
+		formats_hash = g_hash_table_new (g_str_hash, g_str_equal);
 
-		for (i = 0; i < G_N_ELEMENTS (types); i++)
-			g_hash_table_insert (formats,
-					     (gpointer) types [i],
-					     GUINT_TO_POINTER (1));	
+		formats = gdk_pixbuf_get_formats ();
+		list = formats;
+		
+		while (list) {
+			GdkPixbufFormat *format = list->data;
+			gchar **mime_types;
+			
+			mime_types = gdk_pixbuf_format_get_mime_types (format);
+
+			for (i = 0; mime_types[i] != NULL; i++)
+				g_hash_table_insert (formats_hash,
+						     (gpointer) g_strdup (mime_types[i]),
+						     GUINT_TO_POINTER (1));	
+				
+			g_strfreev (mime_types);
+			list = list->next;
+		}
+		g_slist_free (formats);
 	}
 
-	if (g_hash_table_lookup (formats, mime_type))
+	if (g_hash_table_lookup (formats_hash, mime_type))
 		return TRUE;
 
 	return FALSE;
@@ -242,7 +255,7 @@ gnome_icon_lookup (GnomeIconTheme             *icon_theme,
 
   if (result)
     *result = GNOME_ICON_LOOKUP_RESULT_FLAGS_NONE;
-  
+
   /* Look for availibility of custom icon */
   if (custom_icon)
     {
@@ -289,7 +302,7 @@ gnome_icon_lookup (GnomeIconTheme             *icon_theme,
 	return mime_name;
       g_free (mime_name);
       
-      mime_name = make_generic_mime_name (mime_type);
+      mime_name = make_generic_mime_name (mime_type, flags & GNOME_ICON_LOOKUP_FLAGS_EMBEDDING_TEXT);
       if (mime_name && gnome_icon_theme_has_icon (icon_theme, mime_name))
 	return mime_name;
       g_free (mime_name);
